from smarty_base_api import BaseSmartyApiClient, SmartyAPIURL
from resources.lib.common import log_info, log_debug, log_error, log_warning
from resources.lib.settings import settings_instance


class PortalSettingsField:
    LOGO_URL = 'client_logo_url'
    SHOW_TV_CHANNELS = 'show_tvchannels'
    SHOW_INFO = 'show_info'
    SHOW_SETTINGS = 'show_settings'


class UserApiClient(BaseSmartyApiClient):
    def __init__(self, user=None):
        super(UserApiClient, self).__init__(user)
        self._settings = {}
        self._customer_info = []

    def auth(self):
        if self._user.abonement is None or self._user.password is None:
            return UserApiClient.AUTH_DATA_IS_EMPTY

        params = {
            'abonement': self._user.abonement,
            'password': self._user.password
        }

        login_url = self._make_url_with_args("login/", params)

        response = self._request_json(login_url)

        # TODO: make real error handle
        if response['error'] != 0:
            return response['error']

        settings_instance.activation_days_left = response.get('activation_days_left', -1)
        settings_instance.ip_address = response.get('ip_address', '')
        settings_instance.user_first_name = response.get('firstname', '')
        settings_instance.user_last_name = response.get('lastname', '')
        settings_instance.contract_number = response.get('contract_number', '')
        settings_instance.device_id = response.get('device_id', '')

        self._user.authkey = response['authkey']
        self._user.account_id = response['account_id']
        self._user.tariffs_list = response['tariffs_list']
        self._user.last_channel = response['last_channel']
        self._auth_ok = True
        return 0

    def refresh_customer_info(self):
        if not self._auth_ok:
            return UserApiClient.NOT_AUTHORIZED

        url = self._make_url_with_args(SmartyAPIURL.CUSTOMER_INFO, {})
        response = self._request_json(url)

        if 'error' in response and response['error'] != 0:
            # Yep, response does not contain 'error' field
            return response['error']
        self._customer_info = response
        return 0

    def logout(self):
        if not self._auth_ok:
            log_info("Can't logout, user is not authorized", "smartyApiClientlogout")
            return UserApiClient.NOT_AUTHORIZED, None

        logout_url = self._make_url_with_args(SmartyAPIURL.LOGOUT, {})
        response = self._request_json(logout_url)
        if response['error'] == 0:
            self._auth_ok = 0
            self._user.authkey = ''
        return response['error']

    def refresh_settings(self):
        logout_url = self._make_url_with_args(SmartyAPIURL.PORTAL_SETTINGS, {})
        response = self._request_json(logout_url)
        if response['error'] != 0:
            return response['error']
        self._settings = response
        return 0

    def get_setting(self, setting):
        if setting in self._settings:
            return self._settings[setting]
        return None

    @property
    def settings(self):
        return self._settings

    @property
    def customer_info(self):
        return self._customer_info
